@@ -23,3 +23,17 @@ def test_quantify_experiment(tmp_test_data_dir):
     snap = {"snap": 1, "snap2": "str"}
     experiment.save_snapshot(snap)
     assert experiment.load_snapshot() == snap
+
+
+def test_quantify_experiment_load_and_save_text(tmp_test_data_dir):
+    dh.set_datadir(tmp_test_data_dir)
+    tuid = TUID_1D_1PLOT
+    dh.create_exp_folder(tuid)
+    experiment = QuantifyExperiment(tuid)
+
+    text = "text to be saved"
+    rel_path = "directory/file.txt"
+
+    experiment.save_text(text, rel_path)
+
+    assert experiment.load_text(rel_path) == text
